"""UiPath ReAct Agent Constructs.

This module includes UiPath ReAct Agent Loop constructs such as prompts, tools
"""

from .conversational_prompts import (
    PromptUserSettings,
    get_chat_system_prompt,
)
from .conversational_voice_prompts import get_voice_system_prompt
from .prompts import AGENT_SYSTEM_PROMPT_TEMPLATE
from .tools import (
    END_EXECUTION_TOOL,
    RAISE_ERROR_TOOL,
    EndExecutionToolSchemaModel,
    FlowControlToolConfig,
    RaiseErrorToolSchemaModel,
)

__all__ = [
    "AGENT_SYSTEM_PROMPT_TEMPLATE",
    "FlowControlToolConfig",
    "END_EXECUTION_TOOL",
    "RAISE_ERROR_TOOL",
    "EndExecutionToolSchemaModel",
    "RaiseErrorToolSchemaModel",
    "PromptUserSettings",
    "get_chat_system_prompt",
    "get_voice_system_prompt",
]
